@@ -292,21 +292,6 @@ class OverlayNode(object):
 
         return ()
 
-    def __getstate__(self):
-        '''For pickling'''
-
-        return (self.anm, self.overlay_id, self.node_id)
-
-    def __setstate__(self, state):
-        """"""
-
-        # Make self.history = state and last_change and value undefined
-
-        (anm, overlay_id, node_id) = state
-        object.__setattr__(self, 'anm', anm)
-        object.__setattr__(self, 'overlay_id', overlay_id)
-        object.__setattr__(self, 'node_id', node_id)
-
     def __eq__(self, other):
         """"""
 
@@ -746,27 +731,12 @@ class OverlayEdge(object):
         overlay = OverlayGraph(self.anm, key)
         return overlay.edge(self)
 
-    def __getstate__(self):
-        '''For pickling'''
-
-        return (self.anm, self.overlay_id, self.src_id, self.dst_id)
-
     def __lt__(self, other):
         """"""
 
         return (self.src.node_id, self.dst.node_id) \
             < (other.src.node_id, other.dst.node_id)
 
-    def __setstate__(self, state):
-        '''For pickling'''
-
-        self._overlays = state
-        (anm, overlay_id, src_id, dst_id) = state
-        object.__setattr__(self, 'anm', anm)
-        object.__setattr__(self, 'overlay_id', overlay_id)
-        object.__setattr__(self, 'src_id', src_id)
-        object.__setattr__(self, 'dst_id', dst_id)
-
     @property
     def src(self):
         """Source node of edge"""
@@ -955,7 +925,7 @@ class OverlayBase(object):
                                  interface.interface_id)
 
     def edge(self, edge_to_find, dst_to_find=None):
-        '''returns edge in this graph with same src and same edge_id'''
+        '''returns edge in this graph with same src and dst'''
 
         if isinstance(edge_to_find, OverlayEdge):
             src_id = edge_to_find.src
@@ -988,25 +958,21 @@ class OverlayBase(object):
                 src_id = edge_to_find.node_id
                 search_id = dst_to_find.node_id
             else:
-                src_id = edge_to_find.src_id
-                search_id = edge_to_find.edge_id
+                log.warning("Searching by edge_id has been deprecated")
         except AttributeError:
             src_id = None
             search_id = edge_to_find
 
         for (src, dst) in self._graph.edges_iter(src_id):
             try:
-                if self._graph[src][dst]['edge_id'] == search_id:
-                    return OverlayEdge(self._anm, self._overlay_id,
-                            src, dst)
-                elif (src, dst) == (src_id, search_id):
+                if (src, dst) == (src_id, search_id):
 
                     # searching by nodes
 
                     return OverlayEdge(self._anm, self._overlay_id,
                             src, dst)
             except KeyError:
-                pass  # no edge_id for this edge
+                pass  #
 
     def __getitem__(self, key):
         """"""
@@ -1248,6 +1214,7 @@ class OverlayGraph(OverlayBase):
         **kwargs
         ):
         """Update won't append data (which could clobber) if node exists"""
+        nbunch = list(nbunch) # listify in case consumed in try/except
 
         if not retain:
             retain = []
@@ -1273,9 +1240,17 @@ class OverlayGraph(OverlayBase):
                 add_nodes.append((node.node_id, data))
             nbunch = add_nodes
         else:
-            nbunch = (n.node_id for n in nbunch)  # only store the id in overlay
+            try:
+                nbunch = [n.node_id for n in nbunch]  # only store the id in overlay
+            except AttributeError:
+                pass # use nbunch directly as the node IDs
 
         self._graph.add_nodes_from(nbunch, **kwargs)
+        for node in self._graph.nodes():
+            node_data = self._graph.node[node]
+            if "label" not in node_data:
+                node_data["label"] = str(node) # use node id
+
         self._init_interfaces(node_ids)
 
     def add_node(
@@ -1308,14 +1283,28 @@ class OverlayGraph(OverlayBase):
 
     def _init_interfaces(self, nbunch=None):
         """Initialises interfaces"""
+        #TODO: this needs a major refactor!
 
-        if not nbunch:
+        #store the original bunch to check if going input->phy
+        if nbunch is not None:
+            nbunch = list(nbunch) # listify generators
+
+        original_nbunch = {}
+
+        if nbunch is None:
             nbunch = [n for n in self._graph.nodes()]
 
         try:
+            previous = list(nbunch)
             nbunch = list(unwrap_nodes(nbunch))
         except AttributeError:
             pass  # don't need to unwrap
+        else:
+            # record a dict of the new nbunch to the original
+            for index, element in enumerate(nbunch):
+                previous_element = previous[index]
+                if previous_element is not None:
+                    original_nbunch[element] = previous[index]
 
         phy_graph = self._anm.overlay_nx_graphs['phy']
 
@@ -1331,12 +1320,30 @@ class OverlayGraph(OverlayBase):
                             phy_interfaces)
                 self._graph.node[node]['_interfaces'] = data
             except KeyError:
+                #TODO: split this off into seperate function
+                # test if adding from input graph
+                # Note: this has to be done on a node-by-node basis
+                # as ANK allows adding nodes from multiple graphs at once
+                # TODO: warn if adding from multiple overlays at onc
+                if self._overlay_id == "phy" and len(original_nbunch):
+                        # see if adding from input->phy,
+                        # overlay nodes were provided as input
+                        original_node = original_nbunch[node]
+                        if original_node.overlay_id == "input":
+                            # are doing input->phy
+                            # copy the
+                            original_interfaces = original_node.get("_interfaces")
+                            if original_interfaces is not None:
+                                # Initialise with the keys
+                                int_data = {k: {"description": v.get("description"), "type": v.get("type")}
+                                for k, v in original_interfaces.items()}
+                                self._graph.node[node]['_interfaces'] = int_data
 
-# no counterpart in physical graph, initialise
-
-                log.debug('Initialise interfaces for %s in %s' % (node,
-                          self._overlay_id))
-                self._graph.node[node]['_interfaces'] = \
+                else:
+                    # no counterpart in physical graph, initialise
+                    log.debug('Initialise interfaces for %s in %s' % (node,
+                      self._overlay_id))
+                    self._graph.node[node]['_interfaces'] = \
                     {0: {'description': 'loopback', 'type': 'loopback'}}
 
     def allocate_interfaces(self):
@@ -1385,17 +1392,7 @@ class OverlayGraph(OverlayBase):
 
         self._init_interfaces()
 
-        # self._init_interfaces(nbunch)
-
-        def numeric_id(edge):
-            try:
-                return int(edge.edge_id.split('_')[0])
-            except ValueError:
-                return edge  # can't cast to int
-            except AttributeError:
-                return edge  # can't split, eg if not set
-
-        ebunch = sorted(self.edges(), key=numeric_id)
+        ebunch = sorted(self.edges())
 
         for edge in ebunch:
             src = edge.src
@@ -1481,7 +1478,6 @@ class OverlayGraph(OverlayBase):
         except AttributeError:
             pass  # already a list
 
-        retain.append('edge_id')
         retain.append('_interfaces')
         try:
             if len(retain):
@@ -1507,11 +1503,15 @@ class OverlayGraph(OverlayBase):
                     ebunch_out.append((src.node_id, dst.node_id,
                             {'_interfaces': _interfaces}))
                 else:
-
-                    # for nodes - test this occurs still of node-node link (can occur for bgp sessions?)
-
-                    ebunch_out.append((src.node_id, dst.node_id,
-                            {'_interfaces': {}}))
+                    try:
+                        src_id = src.node_id
+                    except AttributeError:
+                        src_id = src # use directly
+                    try:
+                        dst_id = dst.node_id
+                    except AttributeError:
+                        dst_id = dst # use directly
+                    ebunch_out.append((src_id, dst_id, {'_interfaces': {}}))
 
             ebunch = ebunch_out
 
@@ -1577,11 +1577,6 @@ class AbstractNetworkModel(object):
 
         return ()
 
-    def __getstate__(self):
-        '''For pickling'''
-
-        return (self._overlays, self.label_seperator, self.label_attrs)
-
     @property
     def overlay_nx_graphs(self):
         """"""
@@ -1593,15 +1588,6 @@ class AbstractNetworkModel(object):
 
         return overlay_id in self._overlays
 
-    def __setstate__(self, state):
-        '''For pickling'''
-
-        (overlays, label_seperator, label_attrs) = state
-        self._overlays = overlays
-        self.label_seperator = label_seperator
-        self.label_attrs = label_attrs
-        self._build_node_label()
-
     def dump(self):
         import autonetkit.ank_json as ank_json
         data = ank_json.jsonify_anm(self)
