@@ -15,13 +15,10 @@ SETTINGS = autonetkit.config.settings
 
 #TODO: revisit phy_neighbors for eg ASN and use l3_conn instead
 
-#TODO: remove retain edge_id once removed from compiler
 #TODO: note that build network now assumes input graph has interface mappings on nodes/edges
 
 __all__ = ['build']
 
-MESSAGING = ank_messaging.AnkMessaging()
-
 def load(input_graph_string):
     try:
         input_graph = graphml.load_graphml(input_graph_string)
@@ -45,7 +42,6 @@ def load(input_graph_string):
 
 def grid_2d(dim):
     """Creates a 2d grid of dimension dim"""
-    import networkx as nx
     graph = nx.grid_2d_graph(dim, dim)
 
     for node in graph:
@@ -59,10 +55,11 @@ def grid_2d(dim):
         graph.node[node]['ibgp_level'] = 0
 
     mapping = {node: "%s_%s" % (node[0], node[1]) for node in graph}
-    nx.relabel_nodes(graph, mapping, copy=False) # Networkx wipes data if remap with same labels
+    # Networkx wipes data if remap with same labels
+    nx.relabel_nodes(graph, mapping, copy=False)
     for index, (src, dst) in enumerate(graph.edges()):
         graph[src][dst]['type'] = "physical"
-        graph[src][dst]['edge_id'] = "%s_%s_%s" % (index, src, dst) # add global index for sorting
+        # add global index for sorting
 
     SETTINGS['General']['deploy'] = True
     SETTINGS['Deploy Hosts']['internal'] = {
@@ -79,7 +76,6 @@ def initialise(input_graph):
 
     input_undirected = nx.Graph(input_graph)
     g_in = anm.add_overlay("input", graph=input_undirected)
-    anm.add_overlay("input_directed", graph=input_graph, directed=True)
 
 # set defaults
     if not g_in.data.specified_int_names:
@@ -120,6 +116,8 @@ def check_server_asns(anm):
     g_phy = anm['phy']
 
     for server in g_phy.nodes('is_server'):
+        if server.device_subtype in ("SNAT", "FLAT"):
+            continue # Don't warn on ASN for NAT elements
         l3_neighbors = list(server['l3_conn'].neighbors())
         l3_neighbor_asns = set(n.asn for n in l3_neighbors)
         if server.asn not in l3_neighbor_asns:
@@ -145,7 +143,6 @@ def apply_design_rules(anm):
     build_phy(anm)
     g_phy = anm['phy']
 
-    import autonetkit
     #autonetkit.update_http(anm)
     build_l3_connectivity(anm)
 
@@ -153,7 +150,7 @@ def apply_design_rules(anm):
     #autonetkit.update_http(anm)
 
     build_vrf(anm) # need to do before to add loopbacks before ip allocations
-    from autonetkit.design.ip import build_ip, build_ipv4,build_ipv6
+    from autonetkit.design.ip import build_ip, build_ipv4, build_ipv6
     build_ip(anm) # ip infrastructure topology
 
 #TODO: set defaults at the start, rather than inline, ie set g_in.data.address_family then use later
@@ -201,18 +198,18 @@ def apply_design_rules(anm):
     else:
         cisco_build_network.pre_design(anm)
 
-    import autonetkit.design.igp
-    autonetkit.design.igp.build_ospf(anm)
-    autonetkit.design.igp.build_eigrp(anm)
-    autonetkit.design.igp.build_isis(anm)
+    from autonetkit.design.igp import build_ospf, build_eigrp, build_isis
+    build_ospf(anm)
+    build_eigrp(anm)
+    build_isis(anm)
 
-    import autonetkit.design.bgp
-    autonetkit.design.bgp.build_bgp(anm)
+    from autonetkit.design.bgp import build_bgp
+    build_bgp(anm)
     #autonetkit.update_http(anm)
 
-    import autonetkit.design.mpls
-    autonetkit.design.mpls.mpls_te(anm)
-    autonetkit.design.mpls.mpls_oam(anm)
+    from autonetkit.design.mpls import mpls_te, mpls_oam
+    mpls_te(anm)
+    mpls_oam(anm)
 
 # post-processing
     if anm['phy'].data.enable_routing:
@@ -238,9 +235,9 @@ def build(input_graph):
         #print {str(node): {'x': node.x, 'y': node.y} for node in anm['input']}
     except Exception, e:
         # Send the visualisation to help debugging
-            import autonetkit
-            autonetkit.update_http(anm)
-            raise e
+        import autonetkit
+        autonetkit.update_http(anm)
+        raise
     return anm
 
 def vrf_pre_process(anm):
@@ -301,7 +298,7 @@ def build_ibgp_vpn_v4(anm):
     g_bgp = anm['bgp']
     g_ibgp_v4 = anm['ibgp_v4']
     g_vrf = anm['vrf']
-    g_ibgp_vpn_v4= anm.add_overlay("ibgp_vpn_v4", directed=True)
+    g_ibgp_vpn_v4 = anm.add_overlay("ibgp_vpn_v4", directed=True)
 
     ibgp_v4_nodes = list(g_ibgp_v4.nodes())
     pe_nodes = set(g_vrf.nodes(vrf_role = "PE"))
@@ -434,7 +431,7 @@ def build_vrf(anm):
     vrf_add_edges = (e for e in g_l3conn.edges()
            if is_pe_ce_edge(e))
     #TODO: should mark as being towards PE or CE
-    g_vrf.add_edges_from(vrf_add_edges, retain=['edge_id'])
+    g_vrf.add_edges_from(vrf_add_edges)
 
     def is_pe_p_edge(edge):
         src_vrf_role = g_vrf.node(edge.src).vrf_role
@@ -442,7 +439,7 @@ def build_vrf(anm):
         return (src_vrf_role, dst_vrf_role) in (("PE", "P"), ("P", "PE"))
     vrf_add_edges = (e for e in g_l3conn.edges()
             if is_pe_p_edge(e))
-    g_vrf.add_edges_from(vrf_add_edges, retain=['edge_id'])
+    g_vrf.add_edges_from(vrf_add_edges)
 
     build_mpls_ldp(anm)
     # add PE to P edges
@@ -516,12 +513,6 @@ def build_phy(anm):
             if specified_id:
                 interface.specified_id = specified_id # map across
 
-    for node in g_phy.nodes("specified_int_names"):
-        for interface in node:
-            edge = interface.edges()[0]
-            directed_edge = anm['input_directed'].edge(edge)
-            interface.name = directed_edge.name
-
 def build_l3_connectivity(anm):
     """ creates l3_connectivity graph, which is switch nodes aggregated and exploded"""
     #TODO: use this as base for ospf, ebgp, ip, etc rather than exploding in each
@@ -531,13 +522,11 @@ def build_l3_connectivity(anm):
         'specified_int_names',
         'device_subtype', 'platform', 'host', 'syntax'])
     g_l3conn.add_nodes_from(g_in.nodes("is_switch"), retain=['asn'])
-#TODO: check if edge_id needs to be still retained
-    g_l3conn.add_edges_from(g_in.edges(), retain=['edge_id'])
+    g_l3conn.add_edges_from(g_in.edges())
 
-    ank_utils.aggregate_nodes(g_l3conn, g_l3conn.nodes("is_switch"),
-                              retain="edge_id")
-    exploded_edges = ank_utils.explode_nodes(g_l3conn, g_l3conn.nodes("is_switch"),
-                            retain="edge_id")
+    ank_utils.aggregate_nodes(g_l3conn, g_l3conn.nodes("is_switch"))
+    exploded_edges = ank_utils.explode_nodes(g_l3conn,
+        g_l3conn.nodes("is_switch"))
     for edge in exploded_edges:
         edge.multipoint = True
         edge.src_int.multipoint = True
