@@ -338,9 +338,15 @@ class IosBaseCompiler(RouterCompiler):
         for interface in node.physical_interfaces:
             isis_int = self.anm['isis'].interface(interface)
             edges = isis_int.edges()
-            if len(edges) != 1:
-                log.warning('Extended IOS config support not valid for multipoint ISIS connections'
-                            )
+            if not isis_int.is_bound:
+                # Could occur for VRFs
+                log.debug("No ISIS connections for interface %s" % interface)
+                continue
+
+            #TODO: change this to be is_bound and is_multipoint
+            if isis_int.multipoint:
+                log.warning('Extended IOS config support not valid for multipoint ISIS connections on %s'
+                    % interface)
                 continue
 
                 # TODO multipoint handling?
@@ -354,7 +360,7 @@ class IosBaseCompiler(RouterCompiler):
 
             src_type = node.device_subtype
             dst_type = dst['phy'].device_subtype
-            if src_type == 'XRv':
+            if src_type == 'IOS XRv':
                 if dst_type == 'IOSv':
                     interface.isis.hello_padding_disable = True
                 elif dst_type == 'CSR1000v':
@@ -363,15 +369,15 @@ class IosBaseCompiler(RouterCompiler):
                     interface.isis.hello_padding_disable = True
 
             if src_type == 'IOSv':
-                if dst_type == 'XRv':
+                if dst_type == 'IOS XRv':
                     interface.isis.mtu = 1430
 
             if src_type == 'CSR1000v':
-                if dst_type == 'XRv':
+                if dst_type == 'IOS XRv':
                     interface.isis.mtu = 1430
 
             if src_type == 'NX-OSv':
-                if dst_type == 'XRv':
+                if dst_type == 'IOS XRv':
                     interface.mtu = 1430  # for all of interface
                     interface.isis.hello_padding_disable = True
                 elif dst_type == 'IOSv':
