@@ -60,6 +60,11 @@ def manual_ipv4_infrastructure_allocation(anm):
         cd_subnets = [IPNetwork('%s/%s' % (i.subnet.network,
                       i.prefixlen)) for i in connected_interfaces]
 
+
+        if len(cd_subnets) == 0:
+            log.warning("Collision domain %s is not connected to any nodes" % coll_dom)
+            continue
+
         try:
             assert len(set(cd_subnets)) == 1
         except AssertionError:
@@ -84,7 +89,8 @@ def manual_ipv4_infrastructure_allocation(anm):
     infra_blocks = {}
     for (asn, devices) in g_ipv4.groupby('asn').items():
         collision_domains = [d for d in devices if d.collision_domain]
-        subnets = [cd.subnet for cd in collision_domains]
+        subnets = [cd.subnet for cd in collision_domains
+        if cd.subnet is not None] # only if subnet is set
         infra_blocks[asn] = netaddr.cidr_merge(subnets)
 
     g_ipv4.data.infra_blocks = infra_blocks
@@ -120,8 +126,7 @@ def build_ip(anm):
     g_ip.add_nodes_from(g_in)
     g_ip.add_edges_from(g_in.edges(type='physical'))
 
-    ank_utils.aggregate_nodes(g_ip, g_ip.nodes('is_switch'),
-                              retain='edge_id')
+    ank_utils.aggregate_nodes(g_ip, g_ip.nodes('is_switch'))
 
     edges_to_split = [edge for edge in g_ip.edges()
                       if edge.attr_both('is_l3device')]
@@ -129,7 +134,7 @@ def build_ip(anm):
         edge.split = True  # mark as split for use in building nidb
 
     split_created_nodes = list(ank_utils.split(g_ip, edges_to_split,
-                               retain=['edge_id', 'split'],
+                               retain=['split'],
                                id_prepend='cd'))
     for node in split_created_nodes:
         node['graphics'].x = ank_utils.neigh_average(g_ip, node, 'x',
